@@ -116,9 +116,9 @@ static QFont::StyleStrategy ChooseStrategy(FontQuality eff)
 class FontAndCharacterSet : public Font {
 public:
 	CharacterSet characterSet = CharacterSet::Ansi;
-	QFont *pfont = nullptr;
-	FontAndCharacterSet(const FontParameters &fp) {
-		pfont = new QFont;
+	std::unique_ptr<QFont> pfont;
+	explicit FontAndCharacterSet(const FontParameters &fp) {
+		pfont = std::make_unique<QFont>();
 		pfont->setStyleStrategy(ChooseStrategy(fp.extraFontFlag));
 		pfont->setFamily(QString::fromUtf8(fp.faceName));
 		pfont->setPointSizeF(fp.size);
@@ -127,10 +127,6 @@ public:
 
 		characterSet = fp.characterSet;
 	}
-	~FontAndCharacterSet() {
-		delete pfont;
-		pfont = nullptr;
-	}
 };
 
 namespace {
@@ -148,7 +144,7 @@ const FontAndCharacterSet *AsFontAndCharacterSet(const Font *f) {
 
 QFont *FontPointer(const Font *f)
 {
-	return AsFontAndCharacterSet(f)->pfont;
+	return AsFontAndCharacterSet(f)->pfont.get();
 }
 
 }
@@ -921,7 +917,6 @@ PRectangle Window::GetMonitorRect(Point pt)
 class ListWidget : public QListWidget {
 public:
 	explicit ListWidget(QWidget *parent);
-	virtual ~ListWidget();
 
 	void setDelegate(IListBoxDelegate *lbDelegate);
 
@@ -939,7 +934,6 @@ private:
 class ListBoxImpl : public ListBox {
 public:
 	ListBoxImpl() noexcept;
-	~ListBoxImpl() noexcept override = default;
 
 	void SetFont(const Font *font) override;
 	void Create(Window &parent, int ctrlID, Point location,
@@ -950,7 +944,7 @@ public:
 	PRectangle GetDesiredRect() override;
 	int CaretFromEdge() override;
 	void Clear() noexcept override;
-	void Append(char *s, int type = -1) override;
+	void Append(char *s, int type) override;
 	int Length() override;
 	void Select(int n) override;
 	int GetSelection() override;
@@ -1220,7 +1214,6 @@ std::unique_ptr<ListBox> ListBox::Allocate()
 ListWidget::ListWidget(QWidget *parent)
 : QListWidget(parent), delegate(nullptr)
 {}
-ListWidget::~ListWidget() {}
 
 void ListWidget::setDelegate(IListBoxDelegate *lbDelegate)
 {
@@ -1326,7 +1319,7 @@ void Platform::DebugDisplay(const char *s) noexcept
 void Platform::DebugPrintf(const char *format, ...) noexcept
 {
 	char buffer[2000];
-	va_list pArguments;
+	va_list pArguments{};
 	va_start(pArguments, format);
 	vsprintf(buffer, format, pArguments);
 	va_end(pArguments);
