@@ -14,8 +14,8 @@ bool EndsWith(std::wstring_view s, std::wstring_view end);
 bool Contains(std::string const &s, char ch) noexcept;
 
 // Substitute is duplicated instead of templated as it was ambiguous when implemented as a template.
-int Substitute(std::wstring &s, const std::wstring &sFind, const std::wstring &sReplace);
-int Substitute(std::string &s, const std::string &sFind, const std::string &sReplace);
+int Substitute(std::wstring &s, std::wstring_view sFind, std::wstring_view sReplace);
+int Substitute(std::string &s, std::string_view sFind, std::string_view sReplace);
 
 template <typename T>
 int Remove(T &s, const T &sFind) {
@@ -63,6 +63,13 @@ constexpr bool IsADigit(int ch) noexcept {
 	return (ch >= '0') && (ch <= '9');
 }
 
+constexpr bool IsAHexDigit(int ch) noexcept {
+	return
+		((ch >= '0') && (ch <= '9')) ||
+		((ch >= 'a') && (ch <= 'f')) ||
+		((ch >= 'A') && (ch <= 'F'));
+}
+
 constexpr bool IsAlphabetic(int ch) noexcept {
 	return ((ch >= 'A') && (ch <= 'Z')) || ((ch >= 'a') && (ch <= 'z'));
 }
@@ -94,6 +101,16 @@ inline std::vector<GUI::gui_string> ListFromString(const GUI::gui_string &args)
 	return StringSplit(args, '\n');
 }
 
+typedef std::tuple<std::string_view, std::string_view> ViewPair;
+
+// Split view around first separator returning the portion before and after the separator.
+// If the separator is not present then return whole view and an empty view.
+inline ViewPair ViewSplit(std::string_view view, char separator) noexcept {
+	const size_t sepPos = view.find_first_of(separator);
+	std::string_view first = view.substr(0, sepPos);
+	std::string_view second = sepPos == (std::string_view::npos) ? "" : view.substr(sepPos + 1);
+	return { first, second };
+}
 
 // Safer version of string copy functions like strcpy, wcsncpy, etc.
 // Instantiate over fixed length strings of both char and wchar_t.
@@ -118,82 +135,42 @@ constexpr const char *UTF8BOM = "\xef\xbb\xbf";
 
 std::u32string UTF32FromUTF8(std::string_view s);
 unsigned int UTF32Character(const char *utf8) noexcept;
+std::string UTF8FromUTF32(unsigned int uch);
 
 std::string Slash(const std::string &s, bool quoteQuotes);
 unsigned int UnSlash(char *s) noexcept;
 std::string UnSlashString(const char *s);
 std::string UnSlashLowOctalString(const char *s);
 
+unsigned int IntFromHexDigit(int ch) noexcept;
+bool AllBytesHex(std::string_view hexBytes) noexcept;
+unsigned int IntFromHexBytes(std::string_view hexBytes) noexcept;
+std::string UnicodeUnEscape(std::string_view s);
+
 class ILocalize {
 public:
-	virtual GUI::gui_string Text(const char *s, bool retainIfNotFound=true) = 0;
+	virtual GUI::gui_string Text(std::string_view sv, bool retainIfNotFound=true) const = 0;
 };
 
 /**
- * This is a fixed length list of strings suitable for display in combo boxes
+ * ComboMemory is a fixed length list of strings suitable for display in combo boxes
  * as a memory of user entries.
  */
-template < int sz >
-class EntryMemory {
-	std::string entries[sz];
+
+constexpr size_t comboMemorySize = 10;
+
+class ComboMemory {
+	size_t sz;
+	std::vector<std::string> entries;
+	bool Present(const std::string_view sv) const noexcept;
 public:
-	void Insert(const std::string &s) {
-		for (int i = 0; i < sz; i++) {
-			if (entries[i] == s) {
-				for (int j = i; j > 0; j--) {
-					entries[j] = entries[j - 1];
-				}
-				entries[0] = s;
-				return;
-			}
-		}
-		for (int k = sz - 1; k > 0; k--) {
-			entries[k] = entries[k - 1];
-		}
-		entries[0] = s;
-	}
-	void AppendIfNotPresent(const std::string &s) {
-		for (int i = 0; i < sz; i++) {
-			if (entries[i] == s) {
-				return;
-			}
-			if (0 == entries[i].length()) {
-				entries[i] = s;
-				return;
-			}
-		}
-	}
-	void AppendList(const std::string &s, char sep = '|') {
-		int start = 0;
-		int end = 0;
-		while (s[end] != '\0') {
-			end = start;
-			while ((s[end] != sep) && (s[end] != '\0'))
-				++end;
-			AppendIfNotPresent(s.substr(start, end-start));
-			start = end + 1;
-		}
-	}
-	int Length() const noexcept {
-		int len = 0;
-		for (int i = 0; i < sz; i++)
-			if (entries[i].length())
-				len++;
-		return len;
-	}
-	std::string At(int n) const {
-		return entries[n];
-	}
-	std::vector<std::string>AsVector() {
-		std::vector<std::string> ret;
-		for (int i = 0; i < sz; i++) {
-			if (entries[i].length())
-				ret.push_back(entries[i].c_str());
-		}
-		return ret;
-	}
+	ComboMemory(size_t sz_=comboMemorySize);
+	void Insert(std::string_view item);
+	void InsertDeletePrefix(std::string_view item);
+	void Append(std::string_view item);
+	size_t Length() const noexcept;
+	std::string At(size_t n) const;
+	std::vector<std::string> AsVector() const;
 };
 
-typedef EntryMemory < 10 > ComboMemory;
-
 #endif
